import { getChannelMap } from '../api'

interface State {
  id: string
  name: string
}
interface Project {
  channel_id: string
  roles: string[]
  permissions: string[]
  tags: Record<string, string>
}

const authList = ref<Project[]>([])
const tags = ref<Record<string, string>>({})

// 所有下拉的选项
const options = ref<{
  channelType: State[]
  channelQuality: number[]
  distributionStatus: State[]
  caseWithdrawStatus: State[]
  serviceDialogStatus: State[]
  channelStatus: State[]
  channelTags: string[]
  contractConversionType: State[]
  contractType: State[]
  contractDivisionRuleType: State[]
  contractSecondaryDivisionType: State[]
  agreementType: State[]
  channelTaxRate: State[]
  projects: { project_id: string; title: string }[]
}>({
  channelType: [],
  channelQuality: [],
  distributionStatus: [],
  caseWithdrawStatus: [],
  serviceDialogStatus: [],
  channelStatus: [],
  channelTags: [],
  contractConversionType: [],
  contractType: [],
  contractDivisionRuleType: [],
  contractSecondaryDivisionType: [],
  agreementType: [],
  channelTaxRate: [],
  projects: []
})

// 领导
const leaders = ref<State[]>([])

export async function useMap() {
  const channelId = ref('')
  const prefix = ref('')
  async function fetchInfo() {
    await getChannelMap().then((res: any) => {
      const data = res.data
      options.value = {
        channelTags: data.tags_map || [],
        channelType: data.channel_type_map?.slice(0, 3) || [],
        channelStatus: data.channel_status_map || [],
        channelQuality: data.channel_quality_map || [],
        distributionStatus: data.distribution_status_map || [],
        caseWithdrawStatus: data.case_withdraw_status_map || [],
        serviceDialogStatus: data.service_dialog_status_map || [],
        contractConversionType: data.contract_conversion_type_map || [],
        contractType: data.contract_type_map || [],
        contractDivisionRuleType: data.contract_division_rule_type_map || [],
        contractSecondaryDivisionType: data.contract_secondary_division_type_map || [],
        agreementType: data.agreement_type_map || [],
        channelTaxRate: data.channel_tax_rate_map || [],
        projects: data.projects || []
      }
      authList.value = data.channel_auth_map || []
      tags.value = data.tags || {}
      leaders.value = data.leaders_map || []
    })
  }
  if (!authList.value.length) await fetchInfo()

  // 当前项目
  const project = computed(() => {
    return authList.value.find(item => item.channel_id === channelId.value)
  })

  // 是否需要权限控制
  function isAuth(key: string, pre: string = prefix.value) {
    const prop = pre + key
    return Object.prototype.hasOwnProperty.call(tags.value, prop)
  }
  // 有没有权限
  function hasAuth(key: string, pid: string = channelId.value, pre: string = prefix.value) {
    const project = authList.value.find(item => item.channel_id === pid)
    // 暂时先返回true; 有项目ID的必须定义项目ID，要不等于没做权限处理
    if (!project) return true
    const prop = pre + key
    return Object.prototype.hasOwnProperty.call(project.tags, prop)
  }
  // 权限校验
  function checkAuth(key: string, pid: string = channelId.value, pre: string = prefix.value) {
    return isAuth(key, pre) ? hasAuth(key, pid, pre) : true
  }

  return { leaders, options, authList, tags, project, channelId, prefix, isAuth, hasAuth, checkAuth }
}
